Pootle Documentation
====================

Pootle is an online tool that makes the process of translating so much simpler.
It allows crowd-sourced translations, easy volunteer contribution and gives
statistics about the ongoing work.

Pootle is built using the powerful API of the *Translate Toolkit* and the
*Django framework*. If you want to know more about these, you can dive into
their own documentation.

- `Translate Toolkit Documentation
  <http://translate.readthedocs.org/projects/translate-toolkit/en/latest/>`_

- `Django Documentation <https://docs.djangoproject.com/>`_

.. include:: contents.rst.inc
